# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import json

bin_name_string = "xca-%s.msi"


def update_package():
    print("Download/Update package content from upstream binary sources")

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system() == "Windows" and isfile(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini")):
        proxywapt = inifile_readstring(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini"), "global", "http_proxy")
        if proxywapt:
            proxy = {"http": proxywapt, "https": proxywapt}

    # Specific app values
    app_name = control.name
    git_repo = "chris2511/xca"
    url_api = "https://api.github.com/repos/%s/releases/latest" % git_repo
    bin_end = bin_name_string.split("%s")[-1]

    # Getting latest version from official website
    json_load = json.loads(wgets(url_api, proxies=proxy))

    for download in json_load["assets"]:
        if download["name"].endswith(bin_end):
            url_dl = download["browser_download_url"]
            latest_bin = download["name"]
            break

    version = json_load["tag_name"].replace("RELEASE.", "")

    print("Latest " + app_name + " version is: " + version)
    print("Download url is: " + url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: " + latest_bin)
        wget(url_dl, latest_bin, proxies=proxy)

        # Checking version from file
        version_from_file = get_msi_properties(latest_bin)["ProductVersion"]
        if version != version_from_file and version_from_file != "":
            version = version_from_file
            old_latest_bin = latest_bin
            latest_bin = bin_name_string % version
            if isfile(latest_bin):
                remove_file(latest_bin)
            os.rename(old_latest_bin, latest_bin)

        # Changing version of the package
        control.version = "%s-%s" % (version, int(control.version.split("-", 1)[1]) + 1)
        control.save_control_to_wapt(".")
        print("Changing version to " + control.version + " in WAPT\\control")
        print("Update package done. You can now build-upload your package")
    else:
        print("This package is already up-to-date")

    # Deleting outdated binaries
    for bin_in_dir in glob.glob("*.exe") or glob.glob("*.msi") or glob.glob("*.zip"):
        if bin_in_dir != latest_bin:
            print("Outdated binary: " + bin_in_dir + " Deleted")
            remove_file(bin_in_dir)
